@@ -16,6 +16,7 @@
 // OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 // DEALINGS IN THE SOFTWARE.
 
+#![cfg_attr(feature="nightly", allow(incomplete_features))]
 #![cfg_attr(feature="nightly", feature(
     specialization, // for impl FromPyObject<'s> for Vec<...> (#31844)
 ))]
@@ -100,7 +101,7 @@ pub use ffi::Py_ssize_t;
 
 pub use crate::conversion::{FromPyObject, RefFromPyObject, ToPyObject};
 pub use crate::err::{PyErr, PyResult};
-pub use crate::objectprotocol::ObjectProtocol;
+pub use crate::objectprotocol::{ObjectProtocol, NumberProtocol};
 pub use crate::objects::*;
 pub use crate::py_class::CompareOp;
 pub use crate::python::{
